a collection of geometric shapes, which defined the edge and label of sets in a Venn plot.
use plot_shapes() to see some of them.
a tibble with 6 columns
nsets: number of sets, from 1-7.
type: ellipse, circle or triangle
shape_id: to separate different shapes
component: each shape has two components, 'setEdge' and 'setLabel'
id: to separate edges/labels of a shape. For example, 4 sets shape will have ids of 1-4.
xy: coordinates